@@ -1,10 +1,8 @@
 import json
-from os.path import dirname
 from urllib.parse import urlparse
 
 import requests
 import attr
-import yaml
 from requests.cookies import RequestsCookieJar
 from requests.structures import CaseInsensitiveDict
 
@@ -54,10 +52,3 @@ def replay(cassette, cassette_path, status=None, uri=None, diff=None):
             yield replayed
             cheks.check_status_code(replayed)
             diff and store_responses(replayed)
-
-
-def reed_conf(path):
-    project_root = dirname(dirname(__file__))
-    with open(f'{project_root}/{path}') as fd:
-        cassette = yaml.load(fd, Loader=yaml.SafeLoader)
-    return cassette
